package com.fuyuanshen.fyscustomer.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fuyuanshen.common.core.domain.model.LoginUser;
import com.fuyuanshen.common.satoken.utils.LoginHelper;
import com.fuyuanshen.fyscustomer.domain.Customer;
import com.fuyuanshen.fyscustomer.domain.query.UserQueryCriteria;
import com.fuyuanshen.fyscustomer.mapper.CustomerMapper;
import com.fuyuanshen.fyscustomer.service.CustomerService;
import io.undertow.util.BadRequestException;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Set;

/**
 * @author: 默苍璃
 * @date: 2025-07-0114:31
 */
@Service
@RequiredArgsConstructor
public class CustomerServiceImpl extends ServiceImpl<CustomerMapper, Customer> implements CustomerService {

    private final CustomerMapper customerMapper;


    /**
     * 查询所有客户
     *
     * @param criteria
     * @return
     */
    @Override
    public List<Customer> queryAllCustomers(UserQueryCriteria criteria) {
        List<Customer> users = customerMapper.queryAllCustomers(criteria);
        return users;
    }


    /**
     * 新增客户
     *
     * @param customer /
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addCustomer(Customer customer) throws BadRequestException {

        LoginUser loginUser = LoginHelper.getLoginUser();

        UserQueryCriteria userQueryCriteria = new UserQueryCriteria();
        userQueryCriteria.setCustomerName(customer.getUserName());
        List<Customer> customers = customerMapper.queryCustomers(userQueryCriteria);
        if (!customers.isEmpty()) {
            throw new BadRequestException("用户名已存在！！！");
        }
        customer.setUserLevel((byte) (loginUser.getUserLevel() + 1));
        customer.setPid(loginUser.getUserId());

        save(customer);
    }


    /**
     * 修改客户
     *
     * @param resources /
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateCustomer(Customer resources) throws Exception {

    }


    /**
     * 删除客户
     *
     * @param ids /
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delete(Set<Long> ids) {

    }


}
